@@ -19,7 +19,7 @@ use Image::ExifTool qw(:DataAccess);
 use Image::ExifTool::Canon;
 use Image::ExifTool::Exif;
 
-$VERSION = '1.57';
+$VERSION = '1.58';
 
 sub ProcessCanonCustom($$$);
 sub ProcessCanonCustom2($$$);
@@ -1290,9 +1290,19 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
         },
     },
     0x0106 => [{
+        Name => 'AEBShotCount',
+        Condition => '$$self{Model} =~ /\b90D\b/',
+        Notes => 'EOS 90D', # (and who knows what others?)
+        PrintConv => {
+            2 => '2 shots',
+            3 => '3 shots',
+            5 => '5 shots',
+            7 => '7 shots',
+        },
+    },{
         Name => 'AEBShotCount',
         Condition => '$count == 1',
-        Notes => 'one value for some models...',
+        Notes => 'other models storing a single value',
         PrintConv => {
             0 => '3 shots',
             1 => '2 shots',
@@ -1302,7 +1312,7 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
     },{
         Name => 'AEBShotCount',
         Count => 2,
-        Notes => 'two values for others',
+        Notes => 'models storing two values',
         PrintConv => {
             '3 0' => '3 shots',
             '2 1' => '2 shots',
@@ -2098,6 +2108,24 @@ my %convPFn = ( PrintConv => \&ConvertPfn, PrintConvInv => \&ConvertPfnInv );
             '$val=~/(\d+)/ ? $1 : 0',
             '$val=~/(\d+)/ ? $1 : 0',
         ],
+    },{ # (1DXmkIII firmware 1.3)
+        Name => 'ContinuousShootingSpeed',
+        Condition => '$count == 5',
+        Count => 5,
+        PrintConv => [
+            '"Hi $val"',
+            '"Cont $val"',
+            '"Lo $val"',
+            '"Soft $val"',
+            '"Soft LS $val"',
+        ],
+        PrintConvInv => [
+            '$val=~/(\d+)/ ? $1 : 0',
+            '$val=~/(\d+)/ ? $1 : 0',
+            '$val=~/(\d+)/ ? $1 : 0',
+            '$val=~/(\d+)/ ? $1 : 0',
+            '$val=~/(\d+)/ ? $1 : 0',
+        ],
     },{ # others
         Name => 'ContinuousShootingSpeed',
         Count => 3,
@@ -2845,7 +2873,7 @@ Image::ExifTool to read this information.
 
 =head1 AUTHOR
 
-Copyright 2003-2021, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
