@@ -23,7 +23,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Canon;
 
-$VERSION = '1.33';
+$VERSION = '1.37';
 
 sub ProcessCanonVRD($$;$);
 sub WriteCanonVRD($$;$);
@@ -187,6 +187,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITE_PROC => \&Image::ExifTool::WriteBinaryData,
     CHECK_PROC => \&Image::ExifTool::CheckBinaryData,
     WRITABLE => 1,
+    PERMANENT => 1, # (can't add/delete these individually)
     FIRST_ENTRY => 0,
     GROUPS => { 2 => 'Image' },
     DATAMEMBER => [ 0x002 ],   # necessary for writing
@@ -485,6 +486,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITE_PROC => \&Image::ExifTool::WriteBinaryData,
     CHECK_PROC => \&Image::ExifTool::CheckBinaryData,
     WRITABLE => 1,
+    PERMANENT => 1, # (can't add/delete these individually)
     FIRST_ENTRY => 0,
     FORMAT => 'int16s',
     DATAMEMBER => [ 0x58, 0xdc, 0xdf, 0xe0 ], # (required for DataMember and var-format tags)
@@ -999,7 +1001,8 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     PROCESS_PROC => \&ProcessDR4,
     WRITE_PROC => \&ProcessDR4,
     WRITABLE => 1,
-    GROUPS => { 2 => 'Image' },
+    PERMANENT => 1, # (can't add/delete these individually)
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     VARS => { HEX_ID => 1, SORT_PROC => \&SortDR4 },
     NOTES => q{
         Tags written by Canon DPP version 4 in CanonVRD trailers and DR4 files. Each
@@ -1276,7 +1279,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITABLE => 1,
     FIRST_ENTRY => 0,
     FORMAT => 'int32u',
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     # 0 - value: 'IIII' (presumably byte order)
     # 1 - value: 0x00040004 (currently use this for magic number)
     # 2 - value: 6
@@ -1301,7 +1304,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITABLE => 1,
     FIRST_ENTRY => 0,
     FORMAT => 'int32u',
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     0x00 => {
         Name => 'ToneCurveColorSpace',
         PrintConv => {
@@ -1354,7 +1357,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITABLE => 1,
     FIRST_ENTRY => 0,
     FORMAT => 'double',
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     0x02 => 'GammaContrast',
     0x03 => 'GammaColorTone',
     0x04 => 'GammaSaturation',
@@ -1410,7 +1413,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     WRITABLE => 1,
     FIRST_ENTRY => 0,
     FORMAT => 'int32s',
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     0 => { Name => 'CropActive', %noYes },
     1 => 'CropRotatedOriginalWidth',
     2 => 'CropRotatedOriginalHeight',
@@ -1432,7 +1435,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
 # DR4 Stamp Tool tags (ref PH)
 %Image::ExifTool::CanonVRD::StampInfo = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     FORMAT => 'int32u',
     FIRST_ENTRY => 0,
     0x02 => 'StampToolCount',
@@ -1441,7 +1444,7 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
 # DR4 dust delete information (ref PH)
 %Image::ExifTool::CanonVRD::DustInfo = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
-    GROUPS => { 2 => 'Image' },
+    GROUPS => { 1 => 'CanonDR4', 2 => 'Image' },
     FORMAT => 'int32u',
     FIRST_ENTRY => 0,
     0x02 => { Name => 'DustDeleteApplied', %noYes },
@@ -2008,7 +2011,7 @@ sub ProcessCanonVRD($$;$)
             $verbose and print $out "  Creating CanonVRD trailer\n";
             $created = 1;
         }
-        $raf = new File::RandomAccess($dataPt);
+        $raf = File::RandomAccess->new($dataPt);
     }
     # read and validate the footer
     $raf->Seek(-0x40-$offset, 2)    or return 0;
@@ -2046,17 +2049,16 @@ sub ProcessCanonVRD($$;$)
             return 0;
         }
     }
-    # exit quickly if writing and no CanonVRD tags are being edited
-    if ($outfile and not exists $$et{EDIT_DIRS}{CanonVRD}) {
-        print $out "$$et{INDENT}  [nothing changed]\n" if $verbose;
-        return 1 if $outfile eq $dataPt;
-        return Write($outfile, $$dataPt) ? 1 : -1;
-    }
-
     my $vrdType = 'VRD';
 
     if ($outfile) {
         $verbose and not $created and print $out "  Rewriting CanonVRD trailer\n";
+        # exit quickly if writing and no CanonVRD tags are being edited
+        unless (exists $$et{EDIT_DIRS}{CanonVRD}) {
+            print $out "$$et{INDENT}  [nothing changed in CanonVRD]\n" if $verbose;
+            return 1 if $outfile eq $dataPt;
+            return Write($outfile, $$dataPt) ? 1 : -1;
+        }
         # delete CanonVRD information if specified
         my $doDel = $$et{DEL_GROUP}{CanonVRD};
         unless ($doDel) {
@@ -2264,7 +2266,7 @@ files, and as a trailer in JPEG, CRW, CR2 and TIFF images.
 
 =head1 AUTHOR
 
-Copyright 2003-2022, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
