@@ -16,7 +16,7 @@ use Image::ExifTool::Exif;
 use Image::ExifTool::XMP;
 use Image::ExifTool::GPS;
 
-$VERSION = '1.06';
+$VERSION = '1.09';
 
 sub ProcessDJIInfo($$$);
 
@@ -96,6 +96,31 @@ my %convFloat2 = (
     # (nothing yet decoded from device header)
 );
 
+# thermal parameters in APP4 of DJI M3T, H20N, M2EA and some M30T images (ref PH/forum11401)
+%Image::ExifTool::DJI::ThermalParams2 = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 0 => 'APP4', 2 => 'Image' },
+    NOTES => 'Thermal parameters extracted from APP4 of DJI M3T RJPEG files.',
+    0x00 => { Name => 'AmbientTemperature',  Format => 'float', PrintConv => 'sprintf("%.1f C",$val)' }, # (NC)
+    0x04 => { Name => 'ObjectDistance',      Format => 'float', PrintConv => 'sprintf("%.1f m",$val)' },
+    0x08 => { Name => 'Emissivity',          Format => 'float', PrintConv => 'sprintf("%.2f",$val)' },
+    0x0c => { Name => 'RelativeHumidity',    Format => 'float', PrintConv => 'sprintf("%g %%",$val*100)' },
+    0x10 => { Name => 'ReflectedTemperature',Format => 'float', PrintConv => 'sprintf("%.1f C",$val)' },
+    0x65 => { Name => 'IDString',            Format => 'string[16]' }, # (NC)
+);
+
+# thermal parameters in APP4 of some DJI M30T images (ref PH)
+%Image::ExifTool::DJI::ThermalParams3 = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 0 => 'APP4', 2 => 'Image' },
+    NOTES => 'Thermal parameters extracted from APP4 of some DJI RJPEG files.',
+  # 0x00 - 0xaa553800 - params3 magic number 
+    0x04 => { Name => 'RelativeHumidity',    Format => 'int16u' },
+    0x06 => { Name => 'ObjectDistance',      Format => 'int16u', ValueConv => '$val / 10' },
+    0x08 => { Name => 'Emissivity',          Format => 'int16u', ValueConv => '$val / 100' },
+    0x0a => { Name => 'ReflectedTemperature',Format => 'int16u', ValueConv => '$val / 10' },
+);
+
 %Image::ExifTool::DJI::XMP = (
     %Image::ExifTool::XMP::xmpTableDefaults,
     GROUPS => { 0 => 'XMP', 1 => 'XMP-drone-dji', 2 => 'Location' },
@@ -118,9 +143,10 @@ my %convFloat2 = (
         PrintConv    => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
         PrintConvInv => 'Image::ExifTool::GPS::ToDegrees($val, 1, "lat")',
     },
-    GpsLongtitude => { # (sic)
+    GpsLongtitude => { # [sic] (misspelt in DJI original file)
         Name => 'GPSLongtitude',
         Writable => 'real',
+        Avoid => 1, # (in case someone tries to write "GPSLong*")
         PrintConv    => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
         PrintConvInv => 'Image::ExifTool::GPS::ToDegrees($val, 1, "lon")',
     },
@@ -161,7 +187,7 @@ my %convFloat2 = (
 );
 
 #------------------------------------------------------------------------------
-# Process DJI infor (ref PH)
+# Process DJI info (ref PH)
 # Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
 # Returns: 1 on success
 sub ProcessDJIInfo($$$)
@@ -174,6 +200,7 @@ sub ProcessDJIInfo($$$)
         my $buff = substr($$dataPt, $dirStart, $dirLen);
         $dataPt = \$buff;
     }
+    $et->VerboseDir('DJIInfo', undef, length $$dataPt);
     while ($$dataPt =~ /\G\[(.*?)\](?=(\[|$))/sg) {
         my ($tag, $val) = split /:/, $1, 2;
         next unless defined $tag and defined $val;
@@ -210,7 +237,7 @@ the maker notes in images from some DJI Phantom drones.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
