@@ -29,7 +29,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:Public);
 use Image::ExifTool::GPS;
 
-$VERSION = '1.70';
+$VERSION = '1.74';
 
 sub JITTER() { return 2 }       # maximum time jitter
 
@@ -92,7 +92,7 @@ my %isOrient = ( dir => 1, pitch => 1, roll => 1 ); # test for orientation key
 # tags which may exist separately in some formats (eg. CSV)
 my %sepTags = ( dir => 1, pitch => 1, roll => 1, track => 1, speed => 1 );
 
-# conversion factors for GPSSpeed
+# conversion factors for GPSSpeed (standard EXIF units only)
 my %speedConv = (
     'K' => 1.852,       # km/h per knot
     'M' => 1.150779448, # mph per knot
@@ -102,7 +102,14 @@ my %speedConv = (
     'mph' => 'M',
 );
 
-my $secPerDay = 24 * 3600;      # a useful constant
+# all recognized speed conversion factors (non-EXIF included)
+my %otherConv = (
+    'km/h' => 1.852,
+    'mph'  => 1.150779448,
+    'm/s'  => 0.514444,
+);
+
+my $secPerDay = 24 * 3600;  # a useful constant
 
 #------------------------------------------------------------------------------
 # Load GPS track log file
@@ -140,6 +147,7 @@ sub LoadTrackLog($$;$)
     my ($raf, $from, $time, $isDate, $noDate, $noDateChanged, $lastDate, $dateFlarm);
     my ($nmeaStart, $fixSecs, @fixTimes, $lastFix, %nmea, @csvHeadings, $sortFixes);
     my ($canCut, $cutPDOP, $cutHDOP, $cutSats, $e0, $e1, @tmp, $trackFile, $trackTime);
+    my $scaleSpeed;
 
     unless (eval { require Time::Local }) {
         return 'Geotag feature requires Time::Local installed';
@@ -166,7 +174,7 @@ sub LoadTrackLog($$;$)
         # $val is track file name
         if ($et->Open(\*EXIFTOOL_TRKFILE, $val)) {
             $trackFile = $val;
-            $raf = new File::RandomAccess(\*EXIFTOOL_TRKFILE);
+            $raf = File::RandomAccess->new(\*EXIFTOOL_TRKFILE);
             unless ($raf->Read($_, 256)) {
                 close EXIFTOOL_TRKFILE;
                 return "Empty track file '${val}'";
@@ -194,7 +202,7 @@ sub LoadTrackLog($$;$)
     }
     unless ($from) {
         # set up RAF for reading log file in memory
-        $raf = new File::RandomAccess(\$val);
+        $raf = File::RandomAccess->new(\$val);
         $from = 'data';
     }
 
@@ -216,6 +224,9 @@ sub LoadTrackLog($$;$)
         # determine file format
         if (not $format) {
             s/^\xef\xbb\xbf//;          # remove leading BOM if it exists
+            if (/^\xff\xfe|\xfe\xff/) {
+                return "ExifTool doesn't yet read UTF16-format track logs";
+            }
             if (/^<(\?xml|gpx)[\s>]/) { # look for XML or GPX header
                 $format = 'XML';
             # check for NMEA sentence
@@ -246,7 +257,9 @@ sub LoadTrackLog($$;$)
                 $format = 'CSV';
                 # convert recognized headings to our parameter names
                 foreach (@csvHeadings) {
+                    my $head = $_;
                     my $param;
+                    my $xtra = '';
                     s/^GPS ?//; # remove leading "GPS" to simplify regex patterns
                     if (/^Time ?\(seconds\)$/i) { # DJI
                         # DJI CSV log files have a column "Time(seconds)" which is seconds since
@@ -274,7 +287,16 @@ sub LoadTrackLog($$;$)
                         /ref$/i and $param .= 'ref';
                     } elsif (/^(Pos)?Alt/i) {
                         $param = 'alt';
-                    } elsif (/^(Angle)?(Heading|Track)/i) {
+                    } elsif (/^Speed/i) {
+                        $param = 'speed';
+                        # (recognize units in brackets)
+                        if (m{\((mph|km/h|m/s)\)}) {
+                            $scaleSpeed = $otherConv{$1};
+                            $xtra = " in $1";
+                        } else {
+                            $xtra = ' in knots';
+                        }
+                    } elsif (/^(Angle)?(Heading|Track|Bearing)/i) {
                         $param = 'track';
                     } elsif (/^(Angle)?Pitch/i or /^Camera ?Elevation ?Angle/i) {
                         $param = 'pitch';
@@ -284,10 +306,10 @@ sub LoadTrackLog($$;$)
                         $param = 'dir';
                     }
                     if ($param) {
-                        $et->VPrint(2, "CSV column '${_}' is $param\n");
+                        $et->VPrint(2, "CSV column '${head}' is $param$xtra\n");
                         $_ = $param;
                     } else {
-                        $et->VPrint(2, "CSV column '${_}' ignored\n");
+                        $et->VPrint(2, "CSV column '${head}' ignored\n");
                         $_ = '';    # ignore this column
                     }
                 }
@@ -479,9 +501,11 @@ DoneFix:    $isDate = 1;
             my ($param, $date, $secs, %neg);
             foreach $param (@csvHeadings) {
                 my $val = shift @vals;
-                last unless defined $val;
+                last unless defined $val and length($val);
                 next unless $param;
                 if ($param eq 'datetime') {
+                    # (fix formats like "24.07.2016 13:47:30")
+                    $val =~ s/^(\d{2})[^\d](\d{2})[^\d](\d{4}) /$3:$2:$1 /;
                     local $SIG{'__WARN__'} = sub { };
                     my $dateTime = $et->InverseDateTime($val);
                     if ($dateTime) {
@@ -510,6 +534,7 @@ DoneFix:    $isDate = 1;
                     $date = $trackTime;
                     $secs = $val;
                 } else {
+                    $val /= $scaleSpeed if $scaleSpeed and $param eq 'speed';
                     $$fix{$param} = $val;
                     $$has{$param} = 1 if $sepTags{$param};
                 }
@@ -1084,7 +1109,7 @@ sub SetGeoValues($$;$)
                     $iExt = $i1;
                 }
                 if (abs($time - $tn) > $geoMaxExtSecs) {
-                    $err or $err = 'Time is too far from nearest GPS fix';
+                    $err or $err = 'Time is too far from nearest GPS fix'.' '.abs($time-$tn).' '.$geoMaxExtSecs;
                     $et->VPrint(2, '  Nearest fix:     ', PrintFixTime($tn), "\n") if $verbose > 2;
                     $fix = { } if $$geotag{DateTimeOnly};
                 } else {
@@ -1171,24 +1196,29 @@ Category:       foreach $category (qw{pos track alt orient atemp}) {
         # write GPSDateStamp if date included in track log, otherwise delete it
         $gpsDate = sprintf('%.2d:%.2d:%.2d', $t[5]+1900, $t[4]+1, $t[3]) unless $noDate;
         # write GPSAltitude tags if altitude included in track log, otherwise delete them
-        if (defined $$fix{alt}) {
-            $gpsAlt = abs $$fix{alt};
-            $gpsAltRef = ($$fix{alt} < 0 ? 1 : 0);
-        } elsif ($$has{alt} and defined $iExt) {
+        my $alt = $$fix{alt};
+        if (not defined $alt and $$has{alt} and defined $iExt) {
             my $tFix = FindFix($et,'alt',$times,$points,$iExt,$iDir,$geoMaxExtSecs);
-            if ($tFix) {
-                $gpsAlt = abs $$tFix{alt};
-                $gpsAltRef = ($$tFix{alt} < 0 ? 1 : 0);
-            }
+            $alt = $$tFix{alt} if $tFix;
         }
         # set new GPS tag values (EXIF, or XMP if write group is 'xmp')
-        my ($xmp, $exif, @r);
+        my ($xmp, $exif, $qt, @r);
         my %opts = ( Type => 'ValueConv' ); # write ValueConv values
         if ($writeGroup) {
             $opts{Group} = $writeGroup;
             $xmp = ($writeGroup =~ /xmp/i);
             $exif = ($writeGroup =~ /^(exif|gps)$/i);
+            $qt = $writeGroup =~ /^(quicktime|keys|itemlist|userdata)$/i;
         }
+        # set QuickTime GPSCoordinates
+        my $coords = "$$fix{lat} $$fix{lon}";
+        if (defined $alt) {
+            $gpsAlt = abs $alt;
+            $gpsAltRef = ($alt < 0 ? 1 : 0);
+            $coords .= " $alt";
+        }
+        @r = $et->SetNewValue(GPSCoordinates => $coords, %opts);
+        return $err if $qt; # all done if writing to QuickTime only
         # (capture error messages by calling SetNewValue in list context)
         @r = $et->SetNewValue(GPSLatitude => $$fix{lat}, %opts);
         @r = $et->SetNewValue(GPSLongitude => $$fix{lon}, %opts);
@@ -1204,6 +1234,7 @@ Category:       foreach $category (qw{pos track alt orient atemp}) {
             @r = $et->SetNewValue(GPSTrackRef => (defined $$tFix{track} ? 'T' : undef), %opts);
             my ($spd, $ref);
             if (defined($spd = $$tFix{speed})) {
+                # convert to specified units if necessary
                 $ref = $$et{OPTIONS}{GeoSpeedRef};
                 if ($ref and defined $speedConv{$ref}) {
                     $ref = $speedConv{$ref} if $speedConv{$speedConv{$ref}};
@@ -1262,7 +1293,7 @@ Category:       foreach $category (qw{pos track alt orient atemp}) {
                     GPSAltitude GPSAltitudeRef GPSDateStamp GPSTimeStamp GPSDateTime
                     GPSTrack GPSTrackRef GPSSpeed GPSSpeedRef GPSImgDirection
                     GPSImgDirectionRef GPSPitch GPSRoll CameraElevationAngle
-                    AmbientTemperature))
+                    AmbientTemperature GPSCoordinates))
         {
             my @r = $et->SetNewValue($_, undef, %opts);
         }
@@ -1461,7 +1492,7 @@ user-defined tag GPSRoll, must be active.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
