@@ -21,7 +21,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 use Image::ExifTool::GPS;
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 
 sub ExtractObject($$;$);
 sub Get24u($$);
@@ -288,6 +288,12 @@ sub ExtractObject($$;$)
                     my $obj = ExtractObject($et, $plistInfo, $tag);
                     next if not defined $obj;
                     unless ($tagTablePtr) {
+                        # make sure this is a valid structure field name
+                        if (not defined $key or $key !~ /^[-_a-zA-Z0-9]+$/) {
+                            $key = "Tag$i"; # (generate fake tag name if it had illegal characters)
+                        } elsif ($key !~ /^[_a-zA-Z]/) {
+                            $key = "_$key"; # (must begin with alpha or underline)
+                        }
                         $$val{$key} = $obj if defined $obj;
                         next;
                     }
@@ -298,6 +304,7 @@ sub ExtractObject($$;$)
                         my $name = $tag;
                         $name =~ s/([^A-Za-z])([a-z])/$1\u$2/g; # capitalize words
                         $name =~ tr/-_a-zA-Z0-9//dc; # remove illegal characters
+                        $name = "Tag$name" if length($name) < 2 or $name =~ /^[-0-9]/;
                         $tagInfo = { Name => ucfirst($name), List => 1 };
                         if ($$plistInfo{DateFormat}) {
                             $$tagInfo{Groups}{2} = 'Time';
@@ -344,9 +351,9 @@ sub ProcessBinaryPLIST($$;$)
         my $start = $$dirInfo{DirStart};
         if ($start or ($$dirInfo{DirLen} and $$dirInfo{DirLen} != length $$dataPt)) {
             my $buf2 = substr($$dataPt, $start || 0, $$dirInfo{DirLen});
-            $$dirInfo{RAF} = new File::RandomAccess(\$buf2);
+            $$dirInfo{RAF} = File::RandomAccess->new(\$buf2);
         } else {
-            $$dirInfo{RAF} = new File::RandomAccess($dataPt);
+            $$dirInfo{RAF} = File::RandomAccess->new($dataPt);
         }
         my $strt = $$dirInfo{DirStart} || 0;
     }
@@ -443,7 +450,7 @@ This module decodes both the binary and XML-based PLIST format.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
